@@ -12,6 +12,7 @@ OC.L10N.register(
     "Day" : "Day",
     "Week" : "Week",
     "Month" : "Month",
+    "List" : "List",
     "Download" : "Download",
     "Delete" : "Delete",
     "Share link" : "Share link",
@@ -42,12 +43,13 @@ OC.L10N.register(
     "Details" : "Details",
     "Attendees" : "Attendees",
     "Reminders" : "Reminders",
-    "Activity" : "Activity",
     "Close" : "Close",
     "Anniversary" : "Anniversary",
     "Week {number} of {year}" : "Week {number} of {year}",
     "Daily" : "Daily",
     "Weekly" : "Weekly",
+    "next year" : "next year",
+    "today" : "today",
     "When shared show full event" : "When shared show full event",
     "When shared show only busy" : "When shared show only busy",
     "When shared hide this event" : "When shared hide this event",
@@ -56,7 +58,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "Confirmed",
     "Tentative" : "Tentative",
-    "Cancelled" : "Cancelled",
     "Categories" : "Categories",
     "Presentation" : "Presentation",
     "Review" : "Review",
