@@ -17,6 +17,7 @@ OC.L10N.register(
     "can edit" : "kan endra",
     "New calendar" : "Ny kalender",
     "Cancel" : "Avbryt",
+    "Actions" : "Handlingar",
     "Email" : "E-post",
     "Unknown" : "Ukjend",
     "never" : "aldri",
@@ -31,10 +32,10 @@ OC.L10N.register(
     "Details" : "Detaljar",
     "Attendees" : "Deltakarar",
     "Reminders" : "Påminningar",
-    "Activity" : "Aktivitet",
     "Close" : "Lukk",
     "Daily" : "Kvar dag",
     "Weekly" : "Kvar veke",
+    "today" : "i dag",
     "When shared show full event" : "Når delt, vis heile hendinga",
     "When shared show only busy" : "Når delt, vis berre oppteken",
     "When shared hide this event" : "Når delt, gøym denne hendinga",
@@ -43,7 +44,6 @@ OC.L10N.register(
     "Status" : "Status",
     "Confirmed" : "Stadfesta",
     "Tentative" : "Førebels",
-    "Cancelled" : "Avlyst",
     "Mail" : "Post",
     "Play" : "Spel",
     "Global" : "Global"
