@@ -13,6 +13,7 @@ OC.L10N.register(
     "Week" : "Недеља",
     "Month" : "Месец",
     "List" : "Излистај",
+    "Edit name" : "Измени име",
     "Copy private link" : "Копирај приватну везу",
     "Download" : "Преузми",
     "Delete" : "Обриши",
@@ -32,6 +33,7 @@ OC.L10N.register(
     "or" : "или",
     "Actions" : "Радње",
     "Show week numbers" : "Прикажи број седмице",
+    "Show keyboard shortcuts" : "Прикажи пречице тастатуре",
     "Settings & import" : "Поставке & увоз",
     "Notification" : "Обавештење",
     "Email" : "Е-пошта",
